@@ -52,13 +52,13 @@ static Eigen::MatrixXd normalVec(int dim, pcg64 &rs) {
 	});
 }
 
-// wrapper around the fittness function, scales according to boundaries
+// wrapper around the fitness function, scales according to boundaries
 
-class Fittness {
+class Fitness {
 
 public:
 
-	Fittness(callback_type pfunc, const vec &lower_limit,
+	Fitness(callback_type pfunc, const vec &lower_limit,
 			const vec &upper_limit) {
 		func = pfunc;
 		lower = lower_limit;
@@ -122,7 +122,7 @@ class HHOptimizer {
 
 public:
 
-	HHOptimizer(long runid_, Fittness *fitfun_, int dim_, int seed_,
+	HHOptimizer(long runid_, Fitness *fitfun_, int dim_, int seed_,
 			int popsize_, int maxEvaluations_, double stopfitness_) {
 		// runid used to identify a specific run
 		runid = runid_;
@@ -331,7 +331,7 @@ public:
 
 private:
 	long runid;
-	Fittness *fitfun;
+	Fitness *fitfun;
 	int popsize; // population size
 	int dim;
 	int maxEvaluations;
@@ -370,7 +370,7 @@ double* optimizeHH_C(long runid, callback_type func, int dim, int seed,
 		lower_limit.resize(0);
 		upper_limit.resize(0);
 	}
-	Fittness fitfun(func, lower_limit, upper_limit);
+	Fitness fitfun(func, lower_limit, upper_limit);
 	HHOptimizer opt(runid, &fitfun, dim, seed, popsize, maxEvals, stopfitness);
 	try {
 		opt.doOptimize();
