@@ -3,7 +3,7 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory.
 
-__version__ = '1.1.16'
+__version__ = '1.2.0'
 
 __all__ = [
     'cmaes',
@@ -14,6 +14,8 @@ __all__ = [
     'ldecpp',
     'lgcldecpp',
     'hhcpp',
+    'bitecpp',
+    'csmacpp',
     'retry',
     'advretry',
     'multiretry',
