@@ -18,7 +18,7 @@ from numpy.random import Generator, MT19937, SeedSequence
 from scipy.optimize import OptimizeResult, Bounds
 
 from fcmaes.retry import _convertBounds
-from fcmaes.optimizer import dtime, fitting, gclde_cma, logger
+from fcmaes.optimizer import dtime, fitting, de2_cma, logger
 
 os.environ['MKL_DEBUG_CPU_TYPE'] = '5'
 os.environ['MKL_NUM_THREADS'] = '1'
@@ -31,7 +31,7 @@ def minimize(fun,
              logger = None,
              workers = mp.cpu_count(),
              popsize = 31, 
-             min_evaluations = 2250, 
+             min_evaluations = 1500, 
              max_eval_fac = None, 
              check_interval = 100,
              capacity = 500,
@@ -99,7 +99,7 @@ def minimize(fun,
         ``success`` a Boolean flag indicating if the optimizer exited successfully. """
 
     if optimizer is None:
-        optimizer = gclde_cma(min_evaluations, popsize, stop_fittness)     
+        optimizer = de2_cma(min_evaluations, popsize, stop_fittness)     
     if max_eval_fac is None:
         max_eval_fac = int(min(50, 1 + num_retries // check_interval))
     store = Store(bounds, max_eval_fac, check_interval, capacity, logger, num_retries, statistic_num)
@@ -154,8 +154,6 @@ class Store(object):
         self.add_mutex = mp.Lock()    
         self.check_mutex = mp.Lock()                     
         self.xs = mp.RawArray(ct.c_double, capacity * self.dim)
-        self.lowers = mp.RawArray(ct.c_double, capacity * self.dim)
-        self.uppers = mp.RawArray(ct.c_double, capacity * self.dim)
         self.ys = mp.RawArray(ct.c_double, capacity)                  
         self.eval_fac = mp.RawValue(ct.c_double, 1)
         self.count_evals = mp.RawValue(ct.c_long, 0)   
@@ -227,12 +225,10 @@ class Store(object):
         """distance between entries in store."""
         return norm((x - xprev) / self.delta) / math.sqrt(self.dim)
         
-    def replace(self, i, y, xs, lower, upper):
+    def replace(self, i, y, xs):
         """replace entry in store."""
         self.set_y(i, y)
         self.set_x(i, xs)
-        self.set_lower(i, lower)
-        self.set_upper(i, upper)
         
     def crossover(self): # Choose two good entries for recombination
         """indices of store entries to be used for crossover operation."""
@@ -269,13 +265,13 @@ class Store(object):
             x = np.asarray(self.get_x(yi[i]))
             if (xprev is None or self.distance(xprev, x) > 0.15) and \
                 (xprev2 is None or self.distance(xprev2, x) > 0.15): 
-                sortRuns.append( (y, x, self.get_lower(yi[i]), self.get_upper(yi[i])) )
+                sortRuns.append( (y, x) )
                 xprev2 = xprev
                 xprev = x
 
         numStored = min(len(sortRuns),int(0.9*self.capacity)) # keep 90% best 
         for i in range(numStored):
-            self.replace(i, sortRuns[i][0], sortRuns[i][1], sortRuns[i][2], sortRuns[i][3])
+            self.replace(i, sortRuns[i][0], sortRuns[i][1])
         self.num_sorted.value = numStored  
         self.num_stored.value = numStored     
         self.worst_y.value = self.get_y(numStored-1)
@@ -295,7 +291,7 @@ class Store(object):
                     self.sort()
                 ns = self.num_stored.value
                 self.num_stored.value = ns + 1
-                self.replace(ns, y, xs, lower, upper)
+                self.replace(ns, y, xs)
       
     def get_x(self, pid):
         return self.xs[pid*self.dim:(pid+1)*self.dim]
@@ -315,12 +311,6 @@ class Store(object):
     def get_y_best(self):
         return self.best_y.value
 
-    def get_lower(self, pid):
-        return self.lowers[pid*self.dim:(pid+1)*self.dim]
-
-    def get_upper(self, pid):
-        return self.uppers[pid*self.dim:(pid+1)*self.dim]
-
     def get_count_evals(self):
         return self.count_evals.value
   
@@ -333,12 +323,6 @@ class Store(object):
     def set_y(self, pid, y):
         self.ys[pid] = y            
 
-    def set_lower(self, pid, lower):
-        self.lowers[pid*self.dim:(pid+1)*self.dim] = lower[:]
- 
-    def set_upper(self, pid, upper):
-        self.uppers[pid*self.dim:(pid+1)*self.dim] = upper[:]
-
     def get_runs_compare_incr(self, limit):
         with self.add_mutex:
             if self.count_runs.value < limit:
