@@ -15,7 +15,7 @@ import ctypes as ct
 import numpy as np
 from numpy.random import MT19937, Generator
 from scipy.optimize import OptimizeResult
-from fcmaes.cmaescpp import callback_par 
+from fcmaes.cmaescpp import callback_par, call_back_par, freemem, libcmalib
 from fcmaes.cmaes import parallel
 
 os.environ['MKL_DEBUG_CPU_TYPE'] = '5'
@@ -64,7 +64,7 @@ def minimize(fun,
     rg = numpy.random.Generator, optional
         Random generator for creating random guesses.
     runid : int, optional
-        id used to identify the optimization run.
+        id used to identify the run for debugging / logging. 
     workers : int or None, optional
         If not workers is None, function evaluation is performed in parallel for the whole population. 
         Useful for costly objective functions but is deactivated for parallel retry.      
@@ -113,19 +113,6 @@ def minimize(fun,
             fun.stop() # stop all parallel evaluation processes
         return OptimizeResult(x=None, fun=sys.float_info.max, nfev=0, nit=0, status=-1, success=False)  
       
-basepath = os.path.dirname(os.path.abspath(__file__))
-
-if sys.platform.startswith('linux'):
-    libcmalib = ct.cdll.LoadLibrary(basepath + '/lib/libacmalib.so')  
-elif 'mac' in sys.platform:
-    libgtoplib = ct.cdll.LoadLibrary(basepath + '/lib/libacmalib.dylib')  
-else:
-    libcmalib = ct.cdll.LoadLibrary(basepath + '/lib/libacmalib.dll')  
-    
-
-call_back_par = ct.CFUNCTYPE(None, ct.c_int, ct.c_int, \
-                                  ct.POINTER(ct.c_double), ct.POINTER(ct.c_double))  
-
 optimizeGCLDE_C = libcmalib.optimizeGCLDE_C
 optimizeGCLDE_C.argtypes = [ct.c_long, call_back_par, ct.c_int, ct.c_int, \
             ct.POINTER(ct.c_double), ct.POINTER(ct.c_double), \
@@ -133,6 +120,4 @@ optimizeGCLDE_C.argtypes = [ct.c_long, call_back_par, ct.c_int, ct.c_int, \
             ct.c_double, ct.c_double]
 
 optimizeGCLDE_C.restype = ct.POINTER(ct.c_double)         
-freemem = libcmalib.free_mem
-freemem.argtypes = [ct.POINTER(ct.c_double)]
   
