@@ -11,7 +11,7 @@ import time
 import math
 import logging
 
-from fcmaes import cmaes, cmaescpp, decpp, dacpp, hhcpp, gcldecpp, lcldecpp, ldecpp
+from fcmaes import cmaes, cmaescpp, decpp, dacpp, hhcpp, gcldecpp, lcldecpp, ldecpp, csmacpp, bitecpp
 
 _logger = None
 
@@ -390,6 +390,49 @@ class Hh_cpp(Optimizer):
                 stop_fittness = self.stop_fittness,
                 rg=rg, runid = self.get_count_runs(store))
         return ret.x, ret.fun, ret.nfev
+
+class Csma_cpp(Optimizer):
+    """SCMA C++ implementation."""
+   
+    def __init__(self, max_evaluations=50000,
+                 popsize = 31, guess=None, stop_fittness = None, workers = None):        
+        Optimizer.__init__(self, max_evaluations, 'scma cpp')
+        self.popsize = popsize
+        self.stop_fittness = stop_fittness
+        self.guess = guess
+        self.workers = workers
+
+    def minimize(self, fun, bounds, guess=None, sdevs=0.16, rg=Generator(MT19937()), 
+                 store=None, workers = None):
+        ret = csmacpp.minimize(fun, bounds, 
+                self.guess if guess is None else guess,
+                input_sigma=sdevs, 
+                max_evaluations = self.max_eval_num(store), 
+                popsize=self.popsize, 
+                stop_fittness = self.stop_fittness,
+                rg=rg, runid = self.get_count_runs(store))     
+        return ret.x, ret.fun, ret.nfev
+
+class Bite_cpp(Optimizer):
+    """Bite C++ implementation."""
+   
+    def __init__(self, max_evaluations=50000,
+                 popsize = 31, guess=None, stop_fittness = None, workers = None):        
+        Optimizer.__init__(self, max_evaluations, 'bite cpp')
+        self.popsize = popsize
+        self.stop_fittness = stop_fittness
+        self.guess = guess
+        self.workers = workers
+
+    def minimize(self, fun, bounds, guess=None, sdevs=None, rg=Generator(MT19937()), 
+                 store=None, workers = None):
+        ret = bitecpp.minimize(fun, bounds, 
+                self.guess if guess is None else guess,
+                max_evaluations = self.max_eval_num(store), 
+                popsize=self.popsize, 
+                stop_fittness = self.stop_fittness, M = 8,
+                rg=rg, runid = self.get_count_runs(store))     
+        return ret.x, ret.fun, ret.nfev
         
 class Dual_annealing(Optimizer):
     """scipy dual_annealing."""
